@@ -11,12 +11,12 @@ class Quality:
 		self._base = CommandsGroup("quality", core, parent)
 
 	@property
-	def rxLevelMin(self):
-		"""rxLevelMin commands group. 0 Sub-classes, 3 commands."""
-		if not hasattr(self, '_rxLevelMin'):
-			from .Quality_.RxLevelMin import RxLevelMin
-			self._rxLevelMin = RxLevelMin(self._core, self._base)
-		return self._rxLevelMin
+	def rxLevMin(self):
+		"""rxLevMin commands group. 0 Sub-classes, 3 commands."""
+		if not hasattr(self, '_rxLevMin'):
+			from .Quality_.RxLevMin import RxLevMin
+			self._rxLevMin = RxLevMin(self._core, self._base)
+		return self._rxLevMin
 
 	def clone(self) -> 'Quality':
 		"""Clones the group by creating new object from it and its whole existing sub-groups
